#!/usr/bin/tclsh

#########################################################################
#									#
# Script:	example_3a.tcl 						#
#									#
# Started:	16th August, 2001. 					#
#									#
# Completed:	16th August, 2001. 					#
#									#
# Author:	Simon Edwards, (C) Proprius Consulting Ltd		#
#									#
# Purpose:	Simple example program reading in a shopping list!	#
#									#
# Version:	@(#)0.8.2 Modified/renamed for new release (SE)>	#
#									#
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
#									#
#########################################################################

###############################################################################
#    example_3a.tcl - Basic XML parsing example program			      #
#    Copyright (C) 2000-2001 Simon Edwards, Proprius Consulting Ltd           #
#                                                                             #
#    This program is free software; you can redistribute it and/or modify     #
#    it under the terms of the GNU General Public License as published by     #
#    the Free Software Foundation; either version 2 of the License, or        #
#    (at your option) any later version.                                      #
#                                                                             #
#    This program is distributed in the hope that it will be useful,          #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of           #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            #
#    GNU General Public License for more details.                             #
#                                                                             #
#    You should have received a copy of the GNU General Public License        #
#    along with this program; if not, write to the Free Software              #
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA  #
#                                                                             #
#    If you wish to contact the author the following details can be used;     #
#                                                                             #
#    simon.edwards@proprius.co.uk                                             #
###############################################################################


source ../../sxml.tcl

#########################################################################
# The function below is the one we use as our generic program - see the	#
# example tutorial for further details on the arguments used.		#
#########################################################################

proc shopping_list_item {cstack cdata saved_data cattr saved_attr args} {
upvar $saved_data sdata
upvar $saved_attr sattr
global itemno

	#################################################################
	# Since we are scanning for a particular item, just print the 	#
	# data for it.							#
	#################################################################

	puts "$itemno. $cdata"
	incr itemno

	#################################################################
	# Must return 0, or SXML_OK, SXML_ERROR, or SXML_PURGE		#
	#################################################################

	return 0
}

#########################################################################
# A sample program to ensure that a particular element is not processed.#
# Could be done by the above process by checking the stack if you wanted#
# the added complexity. The best idea is to call a function like this	#
# one in those cases.							#
#########################################################################

proc ignoreproc {cstack cdata saved_data cattr saved_attr args} {
	return 0
}

#########################################################################
# Call the initalisation routine - pass in the datafile to parse and 	#
# the id returned must be used to pass in procedure names to use when 	#
# the file is actually parsed.						#
#########################################################################

set id [sxml::init ../data/example_3.xml]
if { $id == -1 } {
	puts "Error: Unable to open test file!"
	exit 1
}

#########################################################################
# Regisiter the two routines written above.				#
#########################################################################

sxml::register_routine $id "shopping:newitem:item" shopping_list_item

#########################################################################
# Parse the data!							#
#########################################################################
set itemno 1
set x [sxml::parse $id]

#########################################################################
# Remove the reference for this file from the parser.			#
#########################################################################

sxml::end $id

exit 0
